==> haskell-yesod-persistent-1.4.2-70-i686.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-persistent
version: 1.4.2
id: yesod-persistent-1.4.2-GQJJGDMJZiTGq2OddpDCkl
key: yesod-persistent-1.4.2-GQJJGDMJZiTGq2OddpDCkl
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>
category: Web, Yesod, Database
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Persist Yesod.Persist.Core
abi: 5e943ab81c3fd01b0603f789f7ee4c6a
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/yesod-persistent-1.4.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/yesod-persistent-1.4.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/yesod-persistent-1.4.2
hs-libraries: HSyesod-persistent-1.4.2-GQJJGDMJZiTGq2OddpDCkl
depends:
    base-4.9.1.0 blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO
    conduit-1.2.11-GzxQexWP3ouJXox0rAqJ5D
    persistent-2.6.1-BZtWNugaCvy4iJ6JpB9ZPy
    persistent-template-2.5.2-DGGdnOuoBhhBpLP87ReqGt
    resource-pool-0.2.3.2-GSqOro7tMX19NOYS758Lwr
    resourcet-1.1.9-DJf1ANdxSraDnKUpiOoSOA transformers-0.5.2.0
    yesod-core-1.4.35-ECdYF3cZgyb9Ing5BpGGKz
haddock-interfaces: /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock
haddock-html: /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-persistent-1.4.2-73-i686.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-persistent
version: 1.4.2
id: yesod-persistent-1.4.2-8Xm3pqQRLYM3IrbHGNQIag
key: yesod-persistent-1.4.2-8Xm3pqQRLYM3IrbHGNQIag
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>
category: Web, Yesod, Database
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Persist Yesod.Persist.Core
abi: d102ed16a516b1ade91f73495d7aa9c0
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/yesod-persistent-1.4.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/yesod-persistent-1.4.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/yesod-persistent-1.4.2
hs-libraries: HSyesod-persistent-1.4.2-8Xm3pqQRLYM3IrbHGNQIag
depends:
    base-4.9.1.0 blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO
    conduit-1.2.11-GzxQexWP3ouJXox0rAqJ5D
    persistent-2.6.1-9ZWX2RZPfKg1JsAfFKOJLS
    persistent-template-2.5.2-HXM023cHXfoDZgA9UioHC9
    resource-pool-0.2.3.2-GSqOro7tMX19NOYS758Lwr
    resourcet-1.1.9-DJf1ANdxSraDnKUpiOoSOA transformers-0.5.2.0
    yesod-core-1.4.35.1-KDHGCjmOZhU9tZs5sLn7si
haddock-interfaces: /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock
haddock-html: /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
